searchData={"items":[{"type":"module","title":"IntervalSigil","doc":"# Interval sigils and conversion utilities\n\nLibrary for defining and converting time intervals.","ref":"IntervalSigil.html"},{"type":"module","title":"Features - IntervalSigil","doc":"- Define time intervals in a human-readable format.\n- Convert intervals to various units, including fractional values.\n- Support for multiple time units within a single definition.","ref":"IntervalSigil.html#module-features"},{"type":"module","title":"Examples - IntervalSigil","doc":"Default conversion to milliseconds\n```elixir\n    iex> import IntervalSigil\n    iex> ~i\"2m 15s\"\n    135000\n```\n\nConversion to alternative units\n```elixir\n    iex> ~i\"2m 15s\"s\n    135\n```\n\nFloating-point results with uppercase sigil `~I`\n```elixir\n    iex> ~I\"6D\"M\n    0.2 # Converts days to months (1 month = 30 days)\n\n    iex> ~I\"75s\"m\n    1.25 # Converts seconds to minutes\n```\n\nExplicit functions `to_integer` and `to_float` to convert time intervals\n```elixir\n    iex> IntervalSigil.to_integer(\"3h 15m\")\n    11700000\n\n    iex> IntervalSigil.to_integer(\"3h 15m\", \"h\")\n    3\n\n    iex> IntervalSigil.to_float(\"3h 15m\", \"h\")\n    3.25\n```","ref":"IntervalSigil.html#module-examples"},{"type":"module","title":"Supported Units - IntervalSigil","doc":"- nanosecond (ns)\n  - microsecond (us)\n  - millisecond (ms, default)\n  - second (s)\n  - minute (m)\n  - hour (h)\n  - day (D)\n  - week (W)\n  - month (M, =30 days)\n  - year (Y, =365 days)","ref":"IntervalSigil.html#module-supported-units"},{"type":"module","title":"Additional Information - IntervalSigil","doc":"- Intervals can include multiple units ordered from largest to smallest, either separated by spaces (e.g., `~i\"1h 30m\"`) or combined (e.g., `~i\"1h30m\"`).\n- The `~i` sigil converts to integer values, while `~I` provides fractional results.","ref":"IntervalSigil.html#module-additional-information"},{"type":"function","title":"IntervalSigil.sigil_I/2","doc":"Handles the sigil ~I for float intervals.\n\nThis sigil converts string representation of an interval to float number of units.","ref":"IntervalSigil.html#sigil_I/2"},{"type":"function","title":"IntervalSigil.sigil_i/2","doc":"Handles the sigil ~i for integer intervals.\n\nThis sigil converts string representation of an interval to integer number of units.","ref":"IntervalSigil.html#sigil_i/2"},{"type":"function","title":"IntervalSigil.to_float/2","doc":"Converts string interval to float","ref":"IntervalSigil.html#to_float/2"},{"type":"function","title":"IntervalSigil.to_integer/2","doc":"Converts string interval to integer","ref":"IntervalSigil.html#to_integer/2"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}